@@ -74,7 +74,6 @@
 #include <Qt3DCore/qabstractskeleton.h>
 // Conversion Includes - Primitive Types
 #include <QAnyStringView>
-#include <qabstractitemmodel.h>
 #include <QString>
 #include <QStringList>
 #include <QStringView>
@@ -89,6 +88,11 @@
 #include <QQueue>
 #include <QSet>
 #include <QStack>
+#include <list>
+#include <map>
+#include <utility>
+#include <unordered_map>
+#include <vector>
 
 // Type indices
 enum : int {
@@ -137,19 +141,20 @@ extern SbkConverter **SbkPySide6_Qt3DCoreTypeConverters;
 
 // Converter indices
 enum : int {
-    SBK_QT3DCORE_QLIST_QT3DCORE_QABSTRACTASPECTPTR_IDX       = 0, // QList<Qt3DCore::QAbstractAspect* >
-    SBK_QT3DCORE_QLIST_QOBJECTPTR_IDX                        = 1, // QList<QObject* >
-    SBK_QT3DCORE_QLIST_QBYTEARRAY_IDX                        = 2, // QList<QByteArray >
-    SBK_QT3DCORE_QLIST_QT3DCORE_QNODEPTR_IDX                 = 3, // QList<Qt3DCore::QNode* >
-    SBK_QT3DCORE_QLIST_QT3DCORE_QNODEID_IDX                  = 4, // QList<Qt3DCore::QNodeId >
-    SBK_QT3DCORE_QLIST_QT3DCORE_QJOINTPTR_IDX                = 5, // QList<Qt3DCore::QJoint* >
-    SBK_QT3DCORE_QLIST_QT3DCORE_QCOMPONENTPTR_IDX            = 6, // QList<Qt3DCore::QComponent* >
-    SBK_QT3DCORE_QLIST_QT3DCORE_QATTRIBUTEPTR_IDX            = 7, // QList<Qt3DCore::QAttribute* >
-    SBK_QT3DCORE_QLIST_QT3DCORE_QENTITYPTR_IDX               = 8, // QList<Qt3DCore::QEntity* >
-    SBK_QT3DCORE_QLIST_QVARIANT_IDX                          = 9, // QList<QVariant >
-    SBK_QT3DCORE_QLIST_QSTRING_IDX                           = 10, // QList<QString >
-    SBK_QT3DCORE_QMAP_QSTRING_QVARIANT_IDX                   = 11, // QMap<QString,QVariant >
-    SBK_Qt3DCore_CONVERTERS_IDX_COUNT                        = 12
+    SBK_QT3DCORE_QLIST_INT_IDX                               = 0, // QList<int >
+    SBK_QT3DCORE_QLIST_QT3DCORE_QABSTRACTASPECTPTR_IDX       = 1, // QList<Qt3DCore::QAbstractAspect* >
+    SBK_QT3DCORE_QLIST_QOBJECTPTR_IDX                        = 2, // QList<QObject* >
+    SBK_QT3DCORE_QLIST_QBYTEARRAY_IDX                        = 3, // QList<QByteArray >
+    SBK_QT3DCORE_QLIST_QT3DCORE_QNODEPTR_IDX                 = 4, // QList<Qt3DCore::QNode* >
+    SBK_QT3DCORE_QLIST_QT3DCORE_QNODEID_IDX                  = 5, // QList<Qt3DCore::QNodeId >
+    SBK_QT3DCORE_QLIST_QT3DCORE_QJOINTPTR_IDX                = 6, // QList<Qt3DCore::QJoint* >
+    SBK_QT3DCORE_QLIST_QT3DCORE_QCOMPONENTPTR_IDX            = 7, // QList<Qt3DCore::QComponent* >
+    SBK_QT3DCORE_QLIST_QT3DCORE_QATTRIBUTEPTR_IDX            = 8, // QList<Qt3DCore::QAttribute* >
+    SBK_QT3DCORE_QLIST_QT3DCORE_QENTITYPTR_IDX               = 9, // QList<Qt3DCore::QEntity* >
+    SBK_QT3DCORE_QLIST_QVARIANT_IDX                          = 10, // QList<QVariant >
+    SBK_QT3DCORE_QLIST_QSTRING_IDX                           = 11, // QList<QString >
+    SBK_QT3DCORE_QMAP_QSTRING_QVARIANT_IDX                   = 12, // QMap<QString,QVariant >
+    SBK_Qt3DCore_CONVERTERS_IDX_COUNT                        = 13
 };
 // Macros for type check
 
