@@ -68,7 +68,6 @@
 #include <QtDBus/qdbusabstractinterface.h>
 // Conversion Includes - Primitive Types
 #include <QAnyStringView>
-#include <qabstractitemmodel.h>
 #include <QString>
 #include <QStringList>
 #include <QStringView>
@@ -83,6 +82,11 @@
 #include <QQueue>
 #include <QSet>
 #include <QStack>
+#include <list>
+#include <map>
+#include <utility>
+#include <unordered_map>
+#include <vector>
 
 // Type indices
 enum : int {
@@ -137,13 +141,14 @@ extern SbkConverter **SbkPySide6_QtDBusTypeConverters;
 
 // Converter indices
 enum : int {
-    SBK_QTDBUS_QLIST_QVARIANT_IDX                            = 0, // QList<QVariant >
-    SBK_QTDBUS_QHASH_QSTRING_QVARIANT_IDX                    = 1, // QHash<QString,QVariant >
-    SBK_QTDBUS_QMAP_QSTRING_QVARIANT_IDX                     = 2, // QMap<QString,QVariant >
-    SBK_QTDBUS_QLIST_QOBJECTPTR_IDX                          = 3, // QList<QObject* >
-    SBK_QTDBUS_QLIST_QBYTEARRAY_IDX                          = 4, // QList<QByteArray >
-    SBK_QTDBUS_QLIST_QSTRING_IDX                             = 5, // QList<QString >
-    SBK_QtDBus_CONVERTERS_IDX_COUNT                          = 6
+    SBK_QTDBUS_QLIST_INT_IDX                                 = 0, // QList<int >
+    SBK_QTDBUS_QLIST_QVARIANT_IDX                            = 1, // QList<QVariant >
+    SBK_QTDBUS_QHASH_QSTRING_QVARIANT_IDX                    = 2, // QHash<QString,QVariant >
+    SBK_QTDBUS_QMAP_QSTRING_QVARIANT_IDX                     = 3, // QMap<QString,QVariant >
+    SBK_QTDBUS_QLIST_QOBJECTPTR_IDX                          = 4, // QList<QObject* >
+    SBK_QTDBUS_QLIST_QBYTEARRAY_IDX                          = 5, // QList<QByteArray >
+    SBK_QTDBUS_QLIST_QSTRING_IDX                             = 6, // QList<QString >
+    SBK_QtDBus_CONVERTERS_IDX_COUNT                          = 7
 };
 // Macros for type check
 
