@@ -66,7 +66,6 @@
 #include <QtHelp/qhelpsearchengine.h>
 // Conversion Includes - Primitive Types
 #include <QAnyStringView>
-#include <qabstractitemmodel.h>
 #include <QString>
 #include <QStringList>
 #include <QStringView>
@@ -81,6 +80,11 @@
 #include <QQueue>
 #include <QSet>
 #include <QStack>
+#include <list>
+#include <map>
+#include <utility>
+#include <unordered_map>
+#include <vector>
 
 // Type indices
 enum : int {
@@ -115,28 +119,29 @@ extern SbkConverter **SbkPySide6_QtHelpTypeConverters;
 
 // Converter indices
 enum : int {
-    SBK_QTHELP_QLIST_QVERSIONNUMBER_IDX                      = 0, // QList<QVersionNumber >
-    SBK_QTHELP_QLIST_INT_IDX                                 = 1, // QList<int >
-    SBK_QTHELP_QLIST_QHELPLINK_IDX                           = 2, // QList<QHelpLink >
-    SBK_QTHELP_QMULTIMAP_QSTRING_QURL_IDX                    = 3, // QMultiMap<QString,QUrl >
-    SBK_QTHELP_QLIST_QACTIONPTR_IDX                          = 4, // QList<QAction* >
-    SBK_QTHELP_QLIST_QHELPSEARCHQUERY_IDX                    = 5, // QList<QHelpSearchQuery >
-    SBK_QTHELP_QLIST_QOBJECTPTR_IDX                          = 6, // QList<QObject* >
-    SBK_QTHELP_QLIST_QBYTEARRAY_IDX                          = 7, // QList<QByteArray >
-    SBK_QTHELP_STD_PAIR_QSTRING_QSTRING_IDX                  = 8, // std::pair<QString,QString >
-    SBK_QTHELP_QLIST_STD_PAIR_QSTRING_QSTRING_IDX            = 9, // QList<std::pair< QString,QString > >
-    SBK_QTHELP_QLIST_QHELPSEARCHRESULT_IDX                   = 10, // QList<QHelpSearchResult >
-    SBK_QTHELP_QMAP_QSTRING_QSTRING_IDX                      = 11, // QMap<QString,QString >
-    SBK_QTHELP_QMAP_QSTRING_QVERSIONNUMBER_IDX               = 12, // QMap<QString,QVersionNumber >
-    SBK_QTHELP_QLIST_QURL_IDX                                = 13, // QList<QUrl >
-    SBK_QTHELP_QLIST_QSTRINGLIST_IDX                         = 14, // QList<QStringList >
-    SBK_QTHELP_QMAP_INT_QVARIANT_IDX                         = 15, // QMap<int,QVariant >
-    SBK_QTHELP_QLIST_QPERSISTENTMODELINDEX_IDX               = 16, // QList<QPersistentModelIndex >
-    SBK_QTHELP_QHASH_INT_QBYTEARRAY_IDX                      = 17, // QHash<int,QByteArray >
-    SBK_QTHELP_QLIST_QVARIANT_IDX                            = 18, // QList<QVariant >
-    SBK_QTHELP_QLIST_QSTRING_IDX                             = 19, // QList<QString >
-    SBK_QTHELP_QMAP_QSTRING_QVARIANT_IDX                     = 20, // QMap<QString,QVariant >
-    SBK_QtHelp_CONVERTERS_IDX_COUNT                          = 21
+    SBK_QTHELP_QLIST_INT_IDX                                 = 0, // QList<int >
+    SBK_QTHELP_QLIST_QVERSIONNUMBER_IDX                      = 1, // QList<QVersionNumber >
+    SBK_QTHELP_QLIST_QMODELINDEX_IDX                         = 2, // QList<QModelIndex >
+    SBK_QTHELP_QLIST_QHELPLINK_IDX                           = 3, // QList<QHelpLink >
+    SBK_QTHELP_QMULTIMAP_QSTRING_QURL_IDX                    = 4, // QMultiMap<QString,QUrl >
+    SBK_QTHELP_QLIST_QACTIONPTR_IDX                          = 5, // QList<QAction* >
+    SBK_QTHELP_QLIST_QHELPSEARCHQUERY_IDX                    = 6, // QList<QHelpSearchQuery >
+    SBK_QTHELP_QLIST_QOBJECTPTR_IDX                          = 7, // QList<QObject* >
+    SBK_QTHELP_QLIST_QBYTEARRAY_IDX                          = 8, // QList<QByteArray >
+    SBK_QTHELP_STD_PAIR_QSTRING_QSTRING_IDX                  = 9, // std::pair<QString,QString >
+    SBK_QTHELP_QLIST_STD_PAIR_QSTRING_QSTRING_IDX            = 10, // QList<std::pair< QString,QString > >
+    SBK_QTHELP_QLIST_QHELPSEARCHRESULT_IDX                   = 11, // QList<QHelpSearchResult >
+    SBK_QTHELP_QMAP_QSTRING_QSTRING_IDX                      = 12, // QMap<QString,QString >
+    SBK_QTHELP_QMAP_QSTRING_QVERSIONNUMBER_IDX               = 13, // QMap<QString,QVersionNumber >
+    SBK_QTHELP_QLIST_QURL_IDX                                = 14, // QList<QUrl >
+    SBK_QTHELP_QLIST_QSTRINGLIST_IDX                         = 15, // QList<QStringList >
+    SBK_QTHELP_QMAP_INT_QVARIANT_IDX                         = 16, // QMap<int,QVariant >
+    SBK_QTHELP_QLIST_QPERSISTENTMODELINDEX_IDX               = 17, // QList<QPersistentModelIndex >
+    SBK_QTHELP_QHASH_INT_QBYTEARRAY_IDX                      = 18, // QHash<int,QByteArray >
+    SBK_QTHELP_QLIST_QVARIANT_IDX                            = 19, // QList<QVariant >
+    SBK_QTHELP_QLIST_QSTRING_IDX                             = 20, // QList<QString >
+    SBK_QTHELP_QMAP_QSTRING_QVARIANT_IDX                     = 21, // QMap<QString,QVariant >
+    SBK_QtHelp_CONVERTERS_IDX_COUNT                          = 22
 };
 // Macros for type check
 
