@@ -77,7 +77,6 @@
 #include <QtMultimedia/qvideosink.h>
 // Conversion Includes - Primitive Types
 #include <QAnyStringView>
-#include <qabstractitemmodel.h>
 #include <QString>
 #include <QStringList>
 #include <QStringView>
@@ -92,6 +91,11 @@
 #include <QQueue>
 #include <QSet>
 #include <QStack>
+#include <list>
+#include <map>
+#include <utility>
+#include <unordered_map>
+#include <vector>
 
 // Type indices
 enum : int {
@@ -175,25 +179,26 @@ extern SbkConverter **SbkPySide6_QtMultimediaTypeConverters;
 
 // Converter indices
 enum : int {
-    SBK_QTMULTIMEDIA_QLIST_QMEDIATIMERANGE_INTERVAL_IDX      = 0, // QList<QMediaTimeRange::Interval >
-    SBK_QTMULTIMEDIA_QLIST_QMEDIAMETADATA_KEY_IDX            = 1, // QList<QMediaMetaData::Key >
-    SBK_QTMULTIMEDIA_QHASH_QMEDIAMETADATA_KEY_QVARIANT_IDX   = 2, // QHash<QMediaMetaData::Key,QVariant >
-    SBK_QTMULTIMEDIA_QLIST_QMEDIAFORMAT_AUDIOCODEC_IDX       = 3, // QList<QMediaFormat::AudioCodec >
-    SBK_QTMULTIMEDIA_QLIST_QMEDIAFORMAT_FILEFORMAT_IDX       = 4, // QList<QMediaFormat::FileFormat >
-    SBK_QTMULTIMEDIA_QLIST_QMEDIAFORMAT_VIDEOCODEC_IDX       = 5, // QList<QMediaFormat::VideoCodec >
-    SBK_QTMULTIMEDIA_QLIST_QSIZE_IDX                         = 6, // QList<QSize >
-    SBK_QTMULTIMEDIA_QLIST_QCAMERAFORMAT_IDX                 = 7, // QList<QCameraFormat >
-    SBK_QTMULTIMEDIA_QLIST_QAUDIOFORMAT_SAMPLEFORMAT_IDX     = 8, // QList<QAudioFormat::SampleFormat >
-    SBK_QTMULTIMEDIA_QLIST_QOBJECTPTR_IDX                    = 9, // QList<QObject* >
-    SBK_QTMULTIMEDIA_QLIST_QBYTEARRAY_IDX                    = 10, // QList<QByteArray >
-    SBK_QTMULTIMEDIA_QLIST_QAUDIODEVICE_IDX                  = 11, // QList<QAudioDevice >
-    SBK_QTMULTIMEDIA_QLIST_QCAMERADEVICE_IDX                 = 12, // QList<QCameraDevice >
-    SBK_QTMULTIMEDIA_QLIST_QIMAGECAPTURE_FILEFORMAT_IDX      = 13, // QList<QImageCapture::FileFormat >
-    SBK_QTMULTIMEDIA_QLIST_QMEDIAMETADATA_IDX                = 14, // QList<QMediaMetaData >
-    SBK_QTMULTIMEDIA_QLIST_QVARIANT_IDX                      = 15, // QList<QVariant >
-    SBK_QTMULTIMEDIA_QLIST_QSTRING_IDX                       = 16, // QList<QString >
-    SBK_QTMULTIMEDIA_QMAP_QSTRING_QVARIANT_IDX               = 17, // QMap<QString,QVariant >
-    SBK_QtMultimedia_CONVERTERS_IDX_COUNT                    = 18
+    SBK_QTMULTIMEDIA_QLIST_INT_IDX                           = 0, // QList<int >
+    SBK_QTMULTIMEDIA_QLIST_QMEDIATIMERANGE_INTERVAL_IDX      = 1, // QList<QMediaTimeRange::Interval >
+    SBK_QTMULTIMEDIA_QLIST_QMEDIAMETADATA_KEY_IDX            = 2, // QList<QMediaMetaData::Key >
+    SBK_QTMULTIMEDIA_QHASH_QMEDIAMETADATA_KEY_QVARIANT_IDX   = 3, // QHash<QMediaMetaData::Key,QVariant >
+    SBK_QTMULTIMEDIA_QLIST_QMEDIAFORMAT_AUDIOCODEC_IDX       = 4, // QList<QMediaFormat::AudioCodec >
+    SBK_QTMULTIMEDIA_QLIST_QMEDIAFORMAT_FILEFORMAT_IDX       = 5, // QList<QMediaFormat::FileFormat >
+    SBK_QTMULTIMEDIA_QLIST_QMEDIAFORMAT_VIDEOCODEC_IDX       = 6, // QList<QMediaFormat::VideoCodec >
+    SBK_QTMULTIMEDIA_QLIST_QSIZE_IDX                         = 7, // QList<QSize >
+    SBK_QTMULTIMEDIA_QLIST_QCAMERAFORMAT_IDX                 = 8, // QList<QCameraFormat >
+    SBK_QTMULTIMEDIA_QLIST_QAUDIOFORMAT_SAMPLEFORMAT_IDX     = 9, // QList<QAudioFormat::SampleFormat >
+    SBK_QTMULTIMEDIA_QLIST_QOBJECTPTR_IDX                    = 10, // QList<QObject* >
+    SBK_QTMULTIMEDIA_QLIST_QBYTEARRAY_IDX                    = 11, // QList<QByteArray >
+    SBK_QTMULTIMEDIA_QLIST_QAUDIODEVICE_IDX                  = 12, // QList<QAudioDevice >
+    SBK_QTMULTIMEDIA_QLIST_QCAMERADEVICE_IDX                 = 13, // QList<QCameraDevice >
+    SBK_QTMULTIMEDIA_QLIST_QIMAGECAPTURE_FILEFORMAT_IDX      = 14, // QList<QImageCapture::FileFormat >
+    SBK_QTMULTIMEDIA_QLIST_QMEDIAMETADATA_IDX                = 15, // QList<QMediaMetaData >
+    SBK_QTMULTIMEDIA_QLIST_QVARIANT_IDX                      = 16, // QList<QVariant >
+    SBK_QTMULTIMEDIA_QLIST_QSTRING_IDX                       = 17, // QList<QString >
+    SBK_QTMULTIMEDIA_QMAP_QSTRING_QVARIANT_IDX               = 18, // QMap<QString,QVariant >
+    SBK_QtMultimedia_CONVERTERS_IDX_COUNT                    = 19
 };
 // Macros for type check
 
