@@ -62,7 +62,6 @@
 #include <QtQuick3D/qquick3dgeometry.h>
 // Conversion Includes - Primitive Types
 #include <QAnyStringView>
-#include <qabstractitemmodel.h>
 #include <QString>
 #include <QStringList>
 #include <QStringView>
@@ -77,6 +76,11 @@
 #include <QQueue>
 #include <QSet>
 #include <QStack>
+#include <list>
+#include <map>
+#include <utility>
+#include <unordered_map>
+#include <vector>
 
 // Type indices
 enum : int {
@@ -105,13 +109,14 @@ extern SbkConverter **SbkPySide6_QtQuick3DTypeConverters;
 
 // Converter indices
 enum : int {
-    SBK_QTQUICK3D_QLIST_QQUICK3DOBJECTPTR_IDX                = 0, // QList<QQuick3DObject* >
-    SBK_QTQUICK3D_QLIST_QOBJECTPTR_IDX                       = 1, // QList<QObject* >
-    SBK_QTQUICK3D_QLIST_QBYTEARRAY_IDX                       = 2, // QList<QByteArray >
-    SBK_QTQUICK3D_QLIST_QVARIANT_IDX                         = 3, // QList<QVariant >
-    SBK_QTQUICK3D_QLIST_QSTRING_IDX                          = 4, // QList<QString >
-    SBK_QTQUICK3D_QMAP_QSTRING_QVARIANT_IDX                  = 5, // QMap<QString,QVariant >
-    SBK_QtQuick3D_CONVERTERS_IDX_COUNT                       = 6
+    SBK_QTQUICK3D_QLIST_INT_IDX                              = 0, // QList<int >
+    SBK_QTQUICK3D_QLIST_QQUICK3DOBJECTPTR_IDX                = 1, // QList<QQuick3DObject* >
+    SBK_QTQUICK3D_QLIST_QOBJECTPTR_IDX                       = 2, // QList<QObject* >
+    SBK_QTQUICK3D_QLIST_QBYTEARRAY_IDX                       = 3, // QList<QByteArray >
+    SBK_QTQUICK3D_QLIST_QVARIANT_IDX                         = 4, // QList<QVariant >
+    SBK_QTQUICK3D_QLIST_QSTRING_IDX                          = 5, // QList<QString >
+    SBK_QTQUICK3D_QMAP_QSTRING_QVARIANT_IDX                  = 6, // QMap<QString,QVariant >
+    SBK_QtQuick3D_CONVERTERS_IDX_COUNT                       = 7
 };
 // Macros for type check
 
