@@ -67,7 +67,6 @@
 #include <QtSql/qsqlrelationaldelegate.h>
 // Conversion Includes - Primitive Types
 #include <QAnyStringView>
-#include <qabstractitemmodel.h>
 #include <QString>
 #include <QStringList>
 #include <QStringView>
@@ -82,6 +81,11 @@
 #include <QQueue>
 #include <QSet>
 #include <QStack>
+#include <list>
+#include <map>
+#include <utility>
+#include <unordered_map>
+#include <vector>
 
 // Type indices
 enum : int {
@@ -130,15 +134,16 @@ extern SbkConverter **SbkPySide6_QtSqlTypeConverters;
 
 // Converter indices
 enum : int {
-    SBK_QTSQL_QLIST_QVARIANT_IDX                             = 0, // QList<QVariant >
-    SBK_QTSQL_QLIST_INT_IDX                                  = 1, // QList<int >
+    SBK_QTSQL_QLIST_INT_IDX                                  = 0, // QList<int >
+    SBK_QTSQL_QLIST_QVARIANT_IDX                             = 1, // QList<QVariant >
     SBK_QTSQL_QLIST_QOBJECTPTR_IDX                           = 2, // QList<QObject* >
     SBK_QTSQL_QLIST_QBYTEARRAY_IDX                           = 3, // QList<QByteArray >
     SBK_QTSQL_QMAP_INT_QVARIANT_IDX                          = 4, // QMap<int,QVariant >
-    SBK_QTSQL_QHASH_INT_QBYTEARRAY_IDX                       = 5, // QHash<int,QByteArray >
-    SBK_QTSQL_QLIST_QSTRING_IDX                              = 6, // QList<QString >
-    SBK_QTSQL_QMAP_QSTRING_QVARIANT_IDX                      = 7, // QMap<QString,QVariant >
-    SBK_QtSql_CONVERTERS_IDX_COUNT                           = 8
+    SBK_QTSQL_QLIST_QMODELINDEX_IDX                          = 5, // QList<QModelIndex >
+    SBK_QTSQL_QHASH_INT_QBYTEARRAY_IDX                       = 6, // QHash<int,QByteArray >
+    SBK_QTSQL_QLIST_QSTRING_IDX                              = 7, // QList<QString >
+    SBK_QTSQL_QMAP_QSTRING_QVARIANT_IDX                      = 8, // QMap<QString,QVariant >
+    SBK_QtSql_CONVERTERS_IDX_COUNT                           = 9
 };
 // Macros for type check
 
