@@ -63,7 +63,6 @@
 #include <QtStateMachine/qsignaltransition.h>
 // Conversion Includes - Primitive Types
 #include <QAnyStringView>
-#include <qabstractitemmodel.h>
 #include <QString>
 #include <QStringList>
 #include <QStringView>
@@ -78,6 +77,11 @@
 #include <QQueue>
 #include <QSet>
 #include <QStack>
+#include <list>
+#include <map>
+#include <utility>
+#include <unordered_map>
+#include <vector>
 
 // Type indices
 enum : int {
@@ -112,16 +116,17 @@ extern SbkConverter **SbkPySide6_QtStateMachineTypeConverters;
 
 // Converter indices
 enum : int {
-    SBK_QTSTATEMACHINE_QLIST_QABSTRACTANIMATIONPTR_IDX       = 0, // QList<QAbstractAnimation* >
-    SBK_QTSTATEMACHINE_QLIST_QOBJECTPTR_IDX                  = 1, // QList<QObject* >
-    SBK_QTSTATEMACHINE_QLIST_QBYTEARRAY_IDX                  = 2, // QList<QByteArray >
-    SBK_QTSTATEMACHINE_QLIST_QABSTRACTSTATEPTR_IDX           = 3, // QList<QAbstractState* >
-    SBK_QTSTATEMACHINE_QLIST_QABSTRACTTRANSITIONPTR_IDX      = 4, // QList<QAbstractTransition* >
-    SBK_QTSTATEMACHINE_QSET_QABSTRACTSTATEPTR_IDX            = 5, // QSet<QAbstractState* >
-    SBK_QTSTATEMACHINE_QLIST_QVARIANT_IDX                    = 6, // QList<QVariant >
-    SBK_QTSTATEMACHINE_QLIST_QSTRING_IDX                     = 7, // QList<QString >
-    SBK_QTSTATEMACHINE_QMAP_QSTRING_QVARIANT_IDX             = 8, // QMap<QString,QVariant >
-    SBK_QtStateMachine_CONVERTERS_IDX_COUNT                  = 9
+    SBK_QTSTATEMACHINE_QLIST_INT_IDX                         = 0, // QList<int >
+    SBK_QTSTATEMACHINE_QLIST_QABSTRACTANIMATIONPTR_IDX       = 1, // QList<QAbstractAnimation* >
+    SBK_QTSTATEMACHINE_QLIST_QOBJECTPTR_IDX                  = 2, // QList<QObject* >
+    SBK_QTSTATEMACHINE_QLIST_QBYTEARRAY_IDX                  = 3, // QList<QByteArray >
+    SBK_QTSTATEMACHINE_QLIST_QABSTRACTSTATEPTR_IDX           = 4, // QList<QAbstractState* >
+    SBK_QTSTATEMACHINE_QLIST_QABSTRACTTRANSITIONPTR_IDX      = 5, // QList<QAbstractTransition* >
+    SBK_QTSTATEMACHINE_QSET_QABSTRACTSTATEPTR_IDX            = 6, // QSet<QAbstractState* >
+    SBK_QTSTATEMACHINE_QLIST_QVARIANT_IDX                    = 7, // QList<QVariant >
+    SBK_QTSTATEMACHINE_QLIST_QSTRING_IDX                     = 8, // QList<QString >
+    SBK_QTSTATEMACHINE_QMAP_QSTRING_QVARIANT_IDX             = 9, // QMap<QString,QVariant >
+    SBK_QtStateMachine_CONVERTERS_IDX_COUNT                  = 10
 };
 // Macros for type check
 
