@@ -55,7 +55,6 @@
 #include <QtSvg/qsvgrenderer.h>
 // Conversion Includes - Primitive Types
 #include <QAnyStringView>
-#include <qabstractitemmodel.h>
 #include <QString>
 #include <QStringList>
 #include <QStringView>
@@ -70,6 +69,11 @@
 #include <QQueue>
 #include <QSet>
 #include <QStack>
+#include <list>
+#include <map>
+#include <utility>
+#include <unordered_map>
+#include <vector>
 
 // Type indices
 enum : int {
@@ -88,12 +92,13 @@ extern SbkConverter **SbkPySide6_QtSvgTypeConverters;
 
 // Converter indices
 enum : int {
-    SBK_QTSVG_QLIST_QOBJECTPTR_IDX                           = 0, // QList<QObject* >
-    SBK_QTSVG_QLIST_QBYTEARRAY_IDX                           = 1, // QList<QByteArray >
-    SBK_QTSVG_QLIST_QVARIANT_IDX                             = 2, // QList<QVariant >
-    SBK_QTSVG_QLIST_QSTRING_IDX                              = 3, // QList<QString >
-    SBK_QTSVG_QMAP_QSTRING_QVARIANT_IDX                      = 4, // QMap<QString,QVariant >
-    SBK_QtSvg_CONVERTERS_IDX_COUNT                           = 5
+    SBK_QTSVG_QLIST_INT_IDX                                  = 0, // QList<int >
+    SBK_QTSVG_QLIST_QOBJECTPTR_IDX                           = 1, // QList<QObject* >
+    SBK_QTSVG_QLIST_QBYTEARRAY_IDX                           = 2, // QList<QByteArray >
+    SBK_QTSVG_QLIST_QVARIANT_IDX                             = 3, // QList<QVariant >
+    SBK_QTSVG_QLIST_QSTRING_IDX                              = 4, // QList<QString >
+    SBK_QTSVG_QMAP_QSTRING_QVARIANT_IDX                      = 5, // QMap<QString,QVariant >
+    SBK_QtSvg_CONVERTERS_IDX_COUNT                           = 6
 };
 // Macros for type check
 
