@@ -61,7 +61,6 @@
 #include <QtTest/qbenchmarkmetric.h>
 // Conversion Includes - Primitive Types
 #include <QAnyStringView>
-#include <qabstractitemmodel.h>
 #include <QString>
 #include <QStringList>
 #include <QStringView>
@@ -76,6 +75,11 @@
 #include <QQueue>
 #include <QSet>
 #include <QStack>
+#include <list>
+#include <map>
+#include <utility>
+#include <unordered_map>
+#include <vector>
 
 // Type indices
 enum : int {
@@ -101,12 +105,13 @@ extern SbkConverter **SbkPySide6_QtTestTypeConverters;
 
 // Converter indices
 enum : int {
-    SBK_QTTEST_QLIST_QVARIANT_IDX                            = 0, // QList<QVariant >
-    SBK_QTTEST_QLIST_QOBJECTPTR_IDX                          = 1, // QList<QObject* >
-    SBK_QTTEST_QLIST_QBYTEARRAY_IDX                          = 2, // QList<QByteArray >
-    SBK_QTTEST_QLIST_QSTRING_IDX                             = 3, // QList<QString >
-    SBK_QTTEST_QMAP_QSTRING_QVARIANT_IDX                     = 4, // QMap<QString,QVariant >
-    SBK_QtTest_CONVERTERS_IDX_COUNT                          = 5
+    SBK_QTTEST_QLIST_INT_IDX                                 = 0, // QList<int >
+    SBK_QTTEST_QLIST_QVARIANT_IDX                            = 1, // QList<QVariant >
+    SBK_QTTEST_QLIST_QOBJECTPTR_IDX                          = 2, // QList<QObject* >
+    SBK_QTTEST_QLIST_QBYTEARRAY_IDX                          = 3, // QList<QByteArray >
+    SBK_QTTEST_QLIST_QSTRING_IDX                             = 4, // QList<QString >
+    SBK_QTTEST_QMAP_QSTRING_QVARIANT_IDX                     = 5, // QMap<QString,QVariant >
+    SBK_QtTest_CONVERTERS_IDX_COUNT                          = 6
 };
 // Macros for type check
 
